# Perceptron_pypi
OneNeuron | Perceptron package

This is only for showing how perceptron works you can try with and and or gate data.

# How to use it

```python
from OneNeuron.Perceptron import Perceptron

## get X and y and then use below commands
model = Perceptron(eta=eta, epochs=epochs)
model.fit(X, y)

```

# References
[Python PyPI docs](https://packaging.python.org/tutorials/packaging-projects/)

[Github Action docs](https://docs.github.com/en/actions/guides/building-and-testing-python#publishing-to-package-registries)